<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问财务报表页面');

// 获取年份和月份参数
$current_year = isset($_GET['year']) ? intval($_GET['year']) : date('Y');
$current_month = isset($_GET['month']) ? intval($_GET['month']) : date('n');

// 获取可用的年份列表
$stmt = $pdo->query("
    SELECT DISTINCT YEAR(record_date) as year 
    FROM finance_records 
    ORDER BY year DESC
");
$available_years = $stmt->fetchAll(PDO::FETCH_COLUMN);
if (empty($available_years)) {
    $available_years = [date('Y')];
}

// 获取门店列表
$stmt = $pdo->query("SELECT id, name FROM stores ORDER BY id");
$stores = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 报表类型
$report_type = isset($_GET['type']) ? $_GET['type'] : 'monthly';
$store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;

// 准备报表数据
switch ($report_type) {
    case 'monthly':
        // 月度收支统计
        $monthly_data = generate_monthly_report($pdo, $current_year, $store_id);
        break;

    case 'category':
        // 类别收支统计
        $category_data = generate_category_report($pdo, $current_year, $current_month, $store_id);
        break;

    case 'store':
        // 门店收支统计
        $store_data = generate_store_report($pdo, $current_year, $current_month);
        break;

    case 'supplier_settlement':
        // 供应商结算报表
        $supplier_data = generate_supplier_settlement_report($pdo, $current_year, $current_month);
        break;

    default:
        // 默认显示月度收支统计
        $monthly_data = generate_monthly_report($pdo, $current_year, $store_id);
        $report_type = 'monthly';
        break;
}

// 生成月度收支统计报表
function generate_monthly_report($pdo, $year, $store_id = 0)
{
    $where_conditions = ["YEAR(record_date) = ?"];
    $params = [$year];

    if ($store_id > 0) {
        $where_conditions[] = "store_id = ?";
        $params[] = $store_id;
    }

    $where_clause = implode(' AND ', $where_conditions);

    // 获取每月收入
    $sql = "
        SELECT 
            MONTH(record_date) as month,
            SUM(CASE WHEN type = 1 THEN amount ELSE 0 END) as income,
            SUM(CASE WHEN type = 2 THEN amount ELSE 0 END) as expense,
            (SUM(CASE WHEN type = 1 THEN amount ELSE 0 END) - SUM(CASE WHEN type = 2 THEN amount ELSE 0 END)) as profit
        FROM finance_records
        WHERE {$where_clause}
        GROUP BY MONTH(record_date)
        ORDER BY month
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $monthly_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 处理数据，确保所有月份都有值
    $result = [];
    $total_income = 0;
    $total_expense = 0;
    $total_profit = 0;

    for ($i = 1; $i <= 12; $i++) {
        $found = false;
        foreach ($monthly_data as $data) {
            if ($data['month'] == $i) {
                $result[$i] = $data;
                $total_income += $data['income'];
                $total_expense += $data['expense'];
                $total_profit += $data['profit'];
                $found = true;
                break;
            }
        }

        if (!$found) {
            $result[$i] = [
                'month' => $i,
                'income' => 0,
                'expense' => 0,
                'profit' => 0
            ];
        }
    }

    return [
        'monthly' => $result,
        'total_income' => $total_income,
        'total_expense' => $total_expense,
        'total_profit' => $total_profit
    ];
}

// 生成类别收支统计报表
function generate_category_report($pdo, $year, $month, $store_id = 0)
{
    $where_conditions = ["YEAR(record_date) = ?"];
    $params = [$year];

    if ($month > 0) {
        $where_conditions[] = "MONTH(record_date) = ?";
        $params[] = $month;
    }

    if ($store_id > 0) {
        $where_conditions[] = "store_id = ?";
        $params[] = $store_id;
    }

    $where_clause = implode(' AND ', $where_conditions);

    // 收入类别统计
    $sql = "
        SELECT 
            category,
            SUM(amount) as total_amount,
            COUNT(*) as record_count
        FROM finance_records
        WHERE {$where_clause} AND type = 1
        GROUP BY category
        ORDER BY total_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $income_categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 支出类别统计
    $sql = "
        SELECT 
            category,
            SUM(amount) as total_amount,
            COUNT(*) as record_count
        FROM finance_records
        WHERE {$where_clause} AND type = 2
        GROUP BY category
        ORDER BY total_amount DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $expense_categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 计算总收入和总支出
    $total_income = 0;
    foreach ($income_categories as $category) {
        $total_income += $category['total_amount'];
    }

    $total_expense = 0;
    foreach ($expense_categories as $category) {
        $total_expense += $category['total_amount'];
    }

    return [
        'income_categories' => $income_categories,
        'expense_categories' => $expense_categories,
        'total_income' => $total_income,
        'total_expense' => $total_expense,
        'profit' => $total_income - $total_expense
    ];
}

// 生成门店收支统计报表
function generate_store_report($pdo, $year, $month = 0)
{
    $where_conditions = ["YEAR(record_date) = ?"];
    $params = [$year];

    if ($month > 0) {
        $where_conditions[] = "MONTH(record_date) = ?";
        $params[] = $month;
    }

    $where_clause = implode(' AND ', $where_conditions);

    // 门店收支统计
    $sql = "
        SELECT 
            s.id as store_id,
            s.name as store_name,
            SUM(CASE WHEN fr.type = 1 THEN fr.amount ELSE 0 END) as income,
            SUM(CASE WHEN fr.type = 2 THEN fr.amount ELSE 0 END) as expense,
            (SUM(CASE WHEN fr.type = 1 THEN fr.amount ELSE 0 END) - SUM(CASE WHEN fr.type = 2 THEN fr.amount ELSE 0 END)) as profit
        FROM stores s
        LEFT JOIN finance_records fr ON s.id = fr.store_id AND {$where_clause}
        GROUP BY s.id, s.name
        ORDER BY profit DESC
    ";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $store_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 计算总收入和总支出
    $total_income = 0;
    $total_expense = 0;
    $total_profit = 0;

    foreach ($store_data as $store) {
        $total_income += $store['income'];
        $total_expense += $store['expense'];
        $total_profit += $store['profit'];
    }

    return [
        'stores' => $store_data,
        'total_income' => $total_income,
        'total_expense' => $total_expense,
        'total_profit' => $total_profit
    ];
}

// 生成供应商结算报表
function generate_supplier_settlement_report($pdo, $year, $month = 0)
{
    // 构造期间条件
    $period = $year;
    if ($month > 0) {
        $period .= '-' . str_pad($month, 2, '0', STR_PAD_LEFT);
    }

    $sql = "
        SELECT 
            fr.id,
            fr.category,
            s.name as supplier_name,
            fr.amount,
            fr.period,
            fr.status,
            fr.description,
            fr.record_date,
            fr.create_time
        FROM finance_records fr
        LEFT JOIN suppliers s ON fr.related_id = s.id
        WHERE fr.type = 3
    ";

    $params = [];

    // 如果有期间限制
    if ($month > 0) {
        $sql .= " AND fr.period = ?";
        $params[] = $period;
    } else {
        $sql .= " AND fr.period LIKE ?";
        $params[] = $year . '%';
    }

    $sql .= " ORDER BY fr.period DESC, fr.status ASC, fr.create_time DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $settlements = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 计算统计数据
    $total_amount = 0;
    $settled_amount = 0;
    $unsettled_amount = 0;
    $settlement_count = count($settlements);

    foreach ($settlements as $settlement) {
        $total_amount += $settlement['amount'];
        if ($settlement['status'] == 2) { // 已结算
            $settled_amount += $settlement['amount'];
        } else { // 未结算
            $unsettled_amount += $settlement['amount'];
        }
    }

    return [
        'settlements' => $settlements,
        'total_amount' => $total_amount,
        'settled_amount' => $settled_amount,
        'unsettled_amount' => $unsettled_amount,
        'settlement_count' => $settlement_count
    ];
}

// 获取月份名称
function get_month_name($month)
{
    $months = [
        1 => '一月',
        2 => '二月',
        3 => '三月',
        4 => '四月',
        5 => '五月',
        6 => '六月',
        7 => '七月',
        8 => '八月',
        9 => '九月',
        10 => '十月',
        11 => '十一月',
        12 => '十二月'
    ];
    return $months[$month] ?? '';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务报表</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt;
                <span>财务报表</span>
            </div>
        </div>

        <div class="content">
            <div class="filter-form">
                <h3>报表选择</h3>
                <form method="get" action="report.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="type">报表类型</label>
                            <select name="type" id="type" onchange="this.form.submit()">
                                <option value="monthly" <?php echo $report_type == 'monthly' ? 'selected' : ''; ?>>月度收支统计</option>
                                <option value="category" <?php echo $report_type == 'category' ? 'selected' : ''; ?>>类别收支统计</option>
                                <option value="store" <?php echo $report_type == 'store' ? 'selected' : ''; ?>>门店收支统计</option>
                                <option value="supplier_settlement" <?php echo $report_type == 'supplier_settlement' ? 'selected' : ''; ?>>供应商结算报表</option>
                            </select>
                        </div>
                        <div class="filter-item">
                            <label for="year">年份</label>
                            <select name="year" id="year" onchange="this.form.submit()">
                                <?php foreach ($available_years as $year): ?>
                                    <option value="<?php echo $year; ?>" <?php echo $current_year == $year ? 'selected' : ''; ?>>
                                        <?php echo $year; ?>年
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <?php if ($report_type != 'monthly'): ?>
                            <div class="filter-item">
                                <label for="month">月份</label>
                                <select name="month" id="month" onchange="this.form.submit()">
                                    <option value="0">全年</option>
                                    <?php for ($i = 1; $i <= 12; $i++): ?>
                                        <option value="<?php echo $i; ?>" <?php echo $current_month == $i ? 'selected' : ''; ?>>
                                            <?php echo $i; ?>月
                                        </option>
                                    <?php endfor; ?>
                                </select>
                            </div>
                        <?php endif; ?>
                        <?php if ($report_type != 'store'): ?>
                            <div class="filter-item">
                                <label for="store_id">门店</label>
                                <select name="store_id" id="store_id" onchange="this.form.submit()">
                                    <option value="0">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo $store_id == $store['id'] ? 'selected' : ''; ?>>
                                            <?php echo $store['name']; ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        <?php endif; ?>
                    </div>
                </form>
            </div>

            <!-- 报表内容 -->
            <?php if ($report_type == 'monthly'): ?>
                <!-- 月度收支统计 -->
                <div class="report-section">
                    <h3><?php echo $current_year; ?>年<?php echo $store_id > 0 ? '门店[' . get_store_name($pdo, $store_id) . ']' : ''; ?>收支统计</h3>

                    <!-- 使用表格样式展示年度统计数据 -->
                    <div class="form-container">
                        <table class="info-table">
                            <tr>
                                <td width="20%">年度总收入：</td>
                                <td>￥<?php echo number_format($monthly_data['total_income'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>年度总支出：</td>
                                <td>￥<?php echo number_format($monthly_data['total_expense'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>年度净利润：</td>
                                <td>￥<?php echo number_format($monthly_data['total_profit'], 2); ?></td>
                            </tr>
                            <?php if ($monthly_data['total_income'] > 0): ?>
                                <tr>
                                    <td>年度利润率：</td>
                                    <td>
                                        <?php
                                        $total_profit_rate = ($monthly_data['total_profit'] / $monthly_data['total_income'] * 100);
                                        echo number_format($total_profit_rate, 2) . '%';
                                        ?>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </table>
                    </div>

                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>月份</th>
                                    <th>收入</th>
                                    <th>支出</th>
                                    <th>利润</th>
                                    <th>利润率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($monthly_data['monthly'] as $month => $data): ?>
                                    <tr>
                                        <td><?php echo get_month_name($month); ?></td>
                                        <td>￥<?php echo number_format($data['income'], 2); ?></td>
                                        <td>￥<?php echo number_format($data['expense'], 2); ?></td>
                                        <td>￥<?php echo number_format($data['profit'], 2); ?></td>
                                        <td>
                                            <?php
                                            $profit_rate = $data['income'] > 0 ? ($data['profit'] / $data['income'] * 100) : 0;
                                            echo number_format($profit_rate, 2) . '%';
                                            ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                                <tr class="summary-row">
                                    <td><strong>合计</strong></td>
                                    <td><strong>￥<?php echo number_format($monthly_data['total_income'], 2); ?></strong></td>
                                    <td><strong>￥<?php echo number_format($monthly_data['total_expense'], 2); ?></strong></td>
                                    <td><strong>￥<?php echo number_format($monthly_data['total_profit'], 2); ?></strong></td>
                                    <td>
                                        <strong>
                                            <?php
                                            $total_profit_rate = $monthly_data['total_income'] > 0 ? ($monthly_data['total_profit'] / $monthly_data['total_income'] * 100) : 0;
                                            echo number_format($total_profit_rate, 2) . '%';
                                            ?>
                                        </strong>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>

            <?php elseif ($report_type == 'category'): ?>
                <!-- 类别收支统计 -->
                <div class="report-section">
                    <h3>
                        <?php echo $current_year; ?>年
                        <?php echo $current_month > 0 ? $current_month . '月' : ''; ?>
                        <?php echo $store_id > 0 ? '门店[' . get_store_name($pdo, $store_id) . ']' : ''; ?>
                        类别收支统计
                    </h3>

                    <!-- 使用表格样式展示类别统计数据 -->
                    <div class="form-container">
                        <table class="info-table">
                            <tr>
                                <td width="20%">总收入：</td>
                                <td>￥<?php echo number_format($category_data['total_income'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>总支出：</td>
                                <td>￥<?php echo number_format($category_data['total_expense'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>净利润：</td>
                                <td>￥<?php echo number_format($category_data['profit'], 2); ?></td>
                            </tr>
                            <?php if ($category_data['total_income'] > 0): ?>
                                <tr>
                                    <td>利润率：</td>
                                    <td>
                                        <?php
                                        $profit_rate = ($category_data['profit'] / $category_data['total_income'] * 100);
                                        echo number_format($profit_rate, 2) . '%';
                                        ?>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </table>
                    </div>

                    <div class="row">
                        <div class="col-6">
                            <h4>收入类别统计</h4>
                            <div class="table-container">
                                <table class="data-table">
                                    <thead>
                                        <tr>
                                            <th>类别</th>
                                            <th>金额</th>
                                            <th>占比</th>
                                            <th>记录数</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (count($category_data['income_categories']) > 0): ?>
                                            <?php foreach ($category_data['income_categories'] as $category): ?>
                                                <tr>
                                                    <td><?php echo $category['category']; ?></td>
                                                    <td>￥<?php echo number_format($category['total_amount'], 2); ?></td>
                                                    <td>
                                                        <?php
                                                        $percentage = $category_data['total_income'] > 0 ? ($category['total_amount'] / $category_data['total_income'] * 100) : 0;
                                                        echo number_format($percentage, 2) . '%';
                                                        ?>
                                                    </td>
                                                    <td><?php echo $category['record_count']; ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="4" class="text-center">暂无收入记录</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>

                        <div class="col-6">
                            <h4>支出类别统计</h4>
                            <div class="table-container">
                                <table class="data-table">
                                    <thead>
                                        <tr>
                                            <th>类别</th>
                                            <th>金额</th>
                                            <th>占比</th>
                                            <th>记录数</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php if (count($category_data['expense_categories']) > 0): ?>
                                            <?php foreach ($category_data['expense_categories'] as $category): ?>
                                                <tr>
                                                    <td><?php echo $category['category']; ?></td>
                                                    <td>￥<?php echo number_format($category['total_amount'], 2); ?></td>
                                                    <td>
                                                        <?php
                                                        $percentage = $category_data['total_expense'] > 0 ? ($category['total_amount'] / $category_data['total_expense'] * 100) : 0;
                                                        echo number_format($percentage, 2) . '%';
                                                        ?>
                                                    </td>
                                                    <td><?php echo $category['record_count']; ?></td>
                                                </tr>
                                            <?php endforeach; ?>
                                        <?php else: ?>
                                            <tr>
                                                <td colspan="4" class="text-center">暂无支出记录</td>
                                            </tr>
                                        <?php endif; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>

            <?php elseif ($report_type == 'store'): ?>
                <!-- 门店收支统计 -->
                <div class="report-section">
                    <h3>
                        <?php echo $current_year; ?>年
                        <?php echo $current_month > 0 ? $current_month . '月' : ''; ?>
                        门店收支统计
                    </h3>

                    <!-- 使用表格样式展示门店统计数据 -->
                    <div class="form-container">
                        <table class="info-table">
                            <tr>
                                <td width="20%">总收入：</td>
                                <td>￥<?php echo number_format($store_data['total_income'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>总支出：</td>
                                <td>￥<?php echo number_format($store_data['total_expense'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>净利润：</td>
                                <td>￥<?php echo number_format($store_data['total_profit'], 2); ?></td>
                            </tr>
                            <?php if ($store_data['total_income'] > 0): ?>
                                <tr>
                                    <td>总利润率：</td>
                                    <td>
                                        <?php
                                        $total_profit_rate = ($store_data['total_profit'] / $store_data['total_income'] * 100);
                                        echo number_format($total_profit_rate, 2) . '%';
                                        ?>
                                    </td>
                                </tr>
                            <?php endif; ?>
                        </table>
                    </div>

                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>门店</th>
                                    <th>收入</th>
                                    <th>支出</th>
                                    <th>利润</th>
                                    <th>利润率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($store_data['stores']) > 0): ?>
                                    <?php foreach ($store_data['stores'] as $store): ?>
                                        <tr>
                                            <td><?php echo $store['store_name']; ?></td>
                                            <td>￥<?php echo number_format($store['income'], 2); ?></td>
                                            <td>￥<?php echo number_format($store['expense'], 2); ?></td>
                                            <td>￥<?php echo number_format($store['profit'], 2); ?></td>
                                            <td>
                                                <?php
                                                $profit_rate = $store['income'] > 0 ? ($store['profit'] / $store['income'] * 100) : 0;
                                                echo number_format($profit_rate, 2) . '%';
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                    <tr class="summary-row">
                                        <td><strong>合计</strong></td>
                                        <td><strong>￥<?php echo number_format($store_data['total_income'], 2); ?></strong></td>
                                        <td><strong>￥<?php echo number_format($store_data['total_expense'], 2); ?></strong></td>
                                        <td><strong>￥<?php echo number_format($store_data['total_profit'], 2); ?></strong></td>
                                        <td>
                                            <strong>
                                                <?php
                                                $total_profit_rate = $store_data['total_income'] > 0 ? ($store_data['total_profit'] / $store_data['total_income'] * 100) : 0;
                                                echo number_format($total_profit_rate, 2) . '%';
                                                ?>
                                            </strong>
                                        </td>
                                    </tr>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="5" class="text-center">暂无数据</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>

            <?php elseif ($report_type == 'supplier_settlement'): ?>
                <!-- 供应商结算报表 -->
                <div class="report-section">
                    <h3>
                        <?php echo $current_year; ?>年
                        <?php echo $current_month > 0 ? $current_month . '月' : ''; ?>
                        供应商结算统计
                    </h3>

                    <!-- 使用表格样式展示供应商结算统计数据 -->
                    <div class="form-container">
                        <table class="info-table">
                            <tr>
                                <td width="20%">结算总额：</td>
                                <td>￥<?php echo number_format($supplier_data['total_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>已结算金额：</td>
                                <td>￥<?php echo number_format($supplier_data['settled_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>未结算金额：</td>
                                <td>￥<?php echo number_format($supplier_data['unsettled_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td>结算记录数：</td>
                                <td><?php echo $supplier_data['settlement_count']; ?> 条</td>
                            </tr>
                        </table>
                    </div>

                    <div class="table-container">
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>供应商</th>
                                    <th>结算周期</th>
                                    <th>金额</th>
                                    <th>状态</th>
                                    <th>记录日期</th>
                                    <th>描述</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (count($supplier_data['settlements']) > 0): ?>
                                    <?php foreach ($supplier_data['settlements'] as $settlement): ?>
                                        <tr>
                                            <td><?php echo $settlement['id']; ?></td>
                                            <td><?php echo $settlement['supplier_name']; ?></td>
                                            <td><?php echo $settlement['period']; ?></td>
                                            <td>￥<?php echo number_format($settlement['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                if ($settlement['status'] == 1) {
                                                    echo '<span class="status-pending">未结算</span>';
                                                } else {
                                                    echo '<span class="status-completed">已结算</span>';
                                                }
                                                ?>
                                            </td>
                                            <td><?php echo $settlement['record_date']; ?></td>
                                            <td><?php echo $settlement['description']; ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td colspan="7" class="text-center">暂无结算记录</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            <?php endif; ?>

        </div>
    </div>
</body>

</html>

<?php
// 辅助函数：获取门店名称
function get_store_name($pdo, $store_id)
{
    $stmt = $pdo->prepare("SELECT name FROM stores WHERE id = ?");
    $stmt->execute([$store_id]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    return $result ? $result['name'] : '未知门店';
}
?>