<?php
// order/list.php - 订单列表管理
session_start();
require_once '../database_config.php';

// 检查权限
check_permission_or_die('order.view');

// 记录访问日志
record_log('访问订单列表页面');

// 设置提示信息变量
$error = null;
$success = null;

// 处理添加订单
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加订单
    if ($_POST['action'] == 'add' && has_permission('order.edit')) {
        $member_id = isset($_POST['member_id']) && !empty($_POST['member_id']) ? intval($_POST['member_id']) : null;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        // 验证商品
        if (!isset($_POST['product_id']) || empty($_POST['product_id'])) {
            $error = '请至少选择一个商品！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 生成订单编号
                $order_no = 'ORD' . date('YmdHis') . rand(100, 999);

                // 计算订单总金额
                $total_amount = 0;
                $product_ids = $_POST['product_id'];
                $quantities = $_POST['quantity'];
                $prices = $_POST['price'];

                for ($i = 0; $i < count($product_ids); $i++) {
                    $total_amount += $prices[$i] * $quantities[$i];
                }

                // 计算折扣（如果是会员）
                $discount_amount = 0;
                $actual_amount = $total_amount;

                if ($member_id) {
                    // 获取会员折扣率
                    $stmt = $pdo->prepare("SELECT m.level_id, l.discount FROM members m JOIN member_levels l ON m.level_id = l.id WHERE m.id = ?");
                    $stmt->execute([$member_id]);
                    $member_info = $stmt->fetch();

                    if ($member_info && $member_info['discount'] < 1) {
                        $discount_rate = $member_info['discount'];
                        $discount_amount = $total_amount * (1 - $discount_rate);
                        $actual_amount = $total_amount - $discount_amount;
                    }
                }

                // 创建订单
                $stmt = $pdo->prepare("
                    INSERT INTO orders (order_no, member_id, store_id, total_amount, discount_amount, actual_amount, status, remark, operator) 
                    VALUES (?, ?, ?, ?, ?, ?, 1, ?, ?)
                ");
                $stmt->execute([
                    $order_no,
                    $member_id,
                    $store_id,
                    $total_amount,
                    $discount_amount,
                    $actual_amount,
                    $remark,
                    $_SESSION['username']
                ]);

                $order_id = $pdo->lastInsertId();

                // 添加订单商品
                $stmt = $pdo->prepare("
                    INSERT INTO order_items (order_id, product_id, product_name, product_code, price, quantity, subtotal) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");

                for ($i = 0; $i < count($product_ids); $i++) {
                    $product_id = $product_ids[$i];
                    $product_name = $_POST['product_name'][$i];
                    $product_code = $_POST['product_code'][$i];
                    $price = $prices[$i];
                    $quantity = $quantities[$i];
                    $subtotal = $price * $quantity;

                    $stmt->execute([
                        $order_id,
                        $product_id,
                        $product_name,
                        $product_code,
                        $price,
                        $quantity,
                        $subtotal
                    ]);

                    // 减少商品库存
                    $stmt_update = $pdo->prepare("UPDATE products SET stock = stock - ? WHERE id = ?");
                    $stmt_update->execute([$quantity, $product_id]);
                }

                // 提交事务
                $pdo->commit();

                // 记录日志
                record_log("创建新订单 ID:{$order_id} 金额:{$actual_amount}");
                $success = '订单创建成功！';
            } catch (PDOException $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            } catch (Exception $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = $e->getMessage();
            }
        }
    }

    // 编辑订单
    elseif ($_POST['action'] == 'edit' && has_permission('order.edit')) {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $member_id = isset($_POST['member_id']) && !empty($_POST['member_id']) ? intval($_POST['member_id']) : null;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 0;
        $total_amount = isset($_POST['total_amount']) ? floatval($_POST['total_amount']) : 0;
        $discount_amount = isset($_POST['discount_amount']) ? floatval($_POST['discount_amount']) : 0;
        $actual_amount = isset($_POST['actual_amount']) ? floatval($_POST['actual_amount']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 检查订单是否存在
                $stmt = $pdo->prepare("SELECT * FROM orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if (!$order) {
                    $error = '订单不存在！';
                } else {
                    // 更新订单信息
                    $stmt = $pdo->prepare("UPDATE orders SET 
                        member_id = ?, store_id = ?, status = ?, 
                        total_amount = ?, discount_amount = ?, actual_amount = ?,
                        remark = ?, update_time = NOW() 
                        WHERE id = ?");
                    $result = $stmt->execute([
                        $member_id,
                        $store_id,
                        $status,
                        $total_amount,
                        $discount_amount,
                        $actual_amount,
                        $remark,
                        $order_id
                    ]);

                    // 处理订单商品
                    if ($result && isset($_POST['product_id']) && !empty($_POST['product_id'])) {
                        // 先删除原有订单商品
                        $stmt = $pdo->prepare("DELETE FROM order_items WHERE order_id = ?");
                        $stmt->execute([$order_id]);

                        // 添加新的订单商品
                        $stmt = $pdo->prepare("
                            INSERT INTO order_items (order_id, product_id, product_name, product_code, price, quantity, subtotal) 
                            VALUES (?, ?, ?, ?, ?, ?, ?)
                        ");

                        $product_ids = $_POST['product_id'];
                        $quantities = $_POST['quantity'];
                        $prices = $_POST['price'];

                        for ($i = 0; $i < count($product_ids); $i++) {
                            $product_id = $product_ids[$i];
                            $product_name = $_POST['product_name'][$i];
                            $product_code = $_POST['product_code'][$i];
                            $price = $prices[$i];
                            $quantity = $quantities[$i];
                            $subtotal = $price * $quantity;

                            $stmt->execute([
                                $order_id,
                                $product_id,
                                $product_name,
                                $product_code,
                                $price,
                                $quantity,
                                $subtotal
                            ]);
                        }
                    }

                    // 提交事务
                    $pdo->commit();
                    record_log("更新订单信息 ID:{$order_id}");
                    $success = '订单信息更新成功！';
                }
            } catch (PDOException $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除订单
    elseif ($_POST['action'] == 'delete' && has_permission('order.edit')) {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($order_id <= 0) {
            $error = '无效的订单ID！';
        } else {
            try {
                // 检查订单状态，只允许删除已取消或已退款的订单
                $stmt = $pdo->prepare("SELECT * FROM orders WHERE id = ?");
                $stmt->execute([$order_id]);
                $order = $stmt->fetch();

                if (!$order) {
                    $error = '订单不存在！';
                } elseif (!in_array($order['status'], [5, 7])) {
                    $error = '只能删除已取消或已退款的订单！';
                } else {
                    // 开始事务
                    $pdo->beginTransaction();

                    // 删除订单商品
                    $stmt = $pdo->prepare("DELETE FROM order_items WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    // 删除订单支付记录
                    $stmt = $pdo->prepare("DELETE FROM order_payments WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    // 删除订单退款记录
                    $stmt = $pdo->prepare("DELETE FROM order_refunds WHERE order_id = ?");
                    $stmt->execute([$order_id]);

                    // 删除订单
                    $stmt = $pdo->prepare("DELETE FROM orders WHERE id = ?");
                    $result = $stmt->execute([$order_id]);

                    if ($result) {
                        // 提交事务
                        $pdo->commit();
                        record_log("删除订单 ID:{$order_id}");
                        $success = '订单删除成功！';
                    } else {
                        // 回滚事务
                        $pdo->rollBack();
                        $error = '订单删除失败！';
                    }
                }
            } catch (PDOException $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取查询参数
$order_no = isset($_GET['order_no']) ? trim($_GET['order_no']) : '';
$member_name = isset($_GET['member_name']) ? trim($_GET['member_name']) : '';
$status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
$start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';

// 构建查询条件
$where_conditions = [];
$params = [];

if (!empty($order_no)) {
    $where_conditions[] = "o.order_no LIKE ?";
    $params[] = "%{$order_no}%";
}

if (!empty($member_name)) {
    $where_conditions[] = "m.name LIKE ?";
    $params[] = "%{$member_name}%";
}

if ($status_filter > 0) {
    $where_conditions[] = "o.status = ?";
    $params[] = $status_filter;
}

if (!empty($start_date)) {
    $where_conditions[] = "DATE(o.create_time) >= ?";
    $params[] = $start_date;
}

if (!empty($end_date)) {
    $where_conditions[] = "DATE(o.create_time) <= ?";
    $params[] = $end_date;
}

$where_clause = !empty($where_conditions) ? " WHERE " . implode(" AND ", $where_conditions) : "";

// 分页设置
$items_per_page = 10;
$current_page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$current_page = max(1, $current_page);

// 获取总记录数
$count_sql = "SELECT COUNT(*) FROM orders o LEFT JOIN members m ON o.member_id = m.id" . $where_clause;
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_items = $stmt->fetchColumn();

// 计算总页数
$total_pages = ceil($total_items / $items_per_page);
$current_page = min($current_page, max(1, $total_pages)); // 确保页码不超过最大页数

// 计算偏移量
$offset = ($current_page - 1) * $items_per_page;

// 获取订单数据
$sql = "SELECT o.*, m.name as member_name, s.name as store_name 
        FROM orders o 
        LEFT JOIN members m ON o.member_id = m.id
        LEFT JOIN stores s ON o.store_id = s.id" . $where_clause . " 
        ORDER BY o.create_time DESC LIMIT " . $offset . ", " . $items_per_page;
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$orders = $stmt->fetchAll();

// 获取所有会员，用于创建订单
$stmt = $pdo->query("SELECT id, name, phone FROM members WHERE status = 1");
$members = $stmt->fetchAll();

// 获取有库存的商品，用于创建订单
$stmt = $pdo->query("SELECT id, name, code, price, stock FROM products WHERE status = 1 AND stock > 0");
$products = $stmt->fetchAll();

// 获取门店列表
$stmt = $pdo->query("SELECT id, name FROM stores WHERE status = 1");
$stores = $stmt->fetchAll();

// 获取订单状态文本
function get_status_text($status)
{
    $status_array = [
        1 => '待付款',
        2 => '已付款',
        3 => '待配送',
        4 => '已完成',
        5 => '已取消',
        6 => '退款中',
        7 => '已退款'
    ];
    return isset($status_array[$status]) ? $status_array[$status] : '未知状态';
}

// 获取订单状态CSS类
function get_status_class($status)
{
    $class_array = [
        1 => 'text-warning',    // 待付款
        2 => 'text-primary',    // 已付款
        3 => 'text-info',       // 待配送
        4 => 'status-active',   // 已完成
        5 => 'status-inactive', // 已取消
        6 => 'text-warning',    // 退款中
        7 => 'status-inactive'  // 已退款
    ];
    return isset($class_array[$status]) ? $class_array[$status] : '';
}

// 获取支付方式文本
function get_payment_type_text($type)
{
    $types = [
        1 => '现金',
        2 => '微信',
        3 => '支付宝',
        4 => '信用卡',
        5 => '储值余额',
        6 => '积分抵扣'
    ];
    return isset($types[$type]) ? $types[$type] : '未知方式';
}

// 获取订单数据（用于编辑）
if (isset($_GET['action']) && $_GET['action'] == 'get_order_data' && isset($_GET['id'])) {
    header('Content-Type: application/json');
    $order_id = intval($_GET['id']);

    try {
        // 获取订单信息
        $stmt = $pdo->prepare("SELECT * FROM orders WHERE id = ?");
        $stmt->execute([$order_id]);
        $order = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$order) {
            echo json_encode(['success' => false, 'message' => '订单不存在']);
            exit;
        }

        // 获取订单商品
        $stmt = $pdo->prepare("SELECT * FROM order_items WHERE order_id = ?");
        $stmt->execute([$order_id]);
        $items = $stmt->fetchAll(PDO::FETCH_ASSOC);

        echo json_encode(['success' => true, 'order' => $order, 'items' => $items]);
    } catch (PDOException $e) {
        echo json_encode(['success' => false, 'message' => $e->getMessage()]);
    }
    exit;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单列表 - <?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单列表</h2>
            <div class="breadcrumb">
                <a href="index.php">订单管理</a> &gt; 订单列表
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 搜索表单 -->
            <div class="filter-form">
                <form method="get" action="list.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="order_no">订单编号</label>
                            <input type="text" id="order_no" name="order_no" value="<?php echo htmlspecialchars($order_no); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="member_name">会员名称</label>
                            <input type="text" id="member_name" name="member_name" value="<?php echo htmlspecialchars($member_name); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="status">订单状态</label>
                            <select id="status" name="status">
                                <option value="0">全部状态</option>
                                <option value="1" <?php echo $status_filter == 1 ? 'selected' : ''; ?>>待付款</option>
                                <option value="2" <?php echo $status_filter == 2 ? 'selected' : ''; ?>>已付款</option>
                                <option value="3" <?php echo $status_filter == 3 ? 'selected' : ''; ?>>待配送</option>
                                <option value="4" <?php echo $status_filter == 4 ? 'selected' : ''; ?>>已完成</option>
                                <option value="5" <?php echo $status_filter == 5 ? 'selected' : ''; ?>>已取消</option>
                                <option value="6" <?php echo $status_filter == 6 ? 'selected' : ''; ?>>退款中</option>
                                <option value="7" <?php echo $status_filter == 7 ? 'selected' : ''; ?>>已退款</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="start_date">开始日期</label>
                            <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>">
                        </div>
                        <div class="filter-item">
                            <label for="end_date">结束日期</label>
                            <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>">
                        </div>
                        <div class="filter-item" style="align-self: flex-end;">
                            <button type="submit" class="btn btn-primary">搜索</button>
                            <a href="list.php" class="btn btn-secondary">重置</a>
                        </div>
                    </div>
                </form>
            </div>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">创建新订单</button>
            </div>

            <!-- 添加订单表单 -->
            <div id="addOrderForm" class="form-container" style="display: none;">
                <h3>创建新订单</h3>
                <form method="post" action="list.php" id="orderForm">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="member_id">选择会员</label>
                        <select id="member_id" name="member_id" class="form-control">
                            <option value="">-- 非会员 --</option>
                            <?php foreach ($members as $member): ?>
                                <option value="<?php echo $member['id']; ?>"><?php echo htmlspecialchars($member['name'] . ' (' . $member['phone'] . ')'); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="store_id">选择门店</label>
                        <select id="store_id" name="store_id" class="form-control" required>
                            <?php foreach ($stores as $store): ?>
                                <option value="<?php echo $store['id']; ?>"><?php echo htmlspecialchars($store['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <!-- 商品选择 -->
                    <div class="form-group">
                        <label>选择商品</label>
                        <div class="table-container">
                            <table class="data-table" id="productTable">
                                <thead>
                                    <tr>
                                        <th>商品名称</th>
                                        <th>单价</th>
                                        <th>数量</th>
                                        <th>小计</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody id="orderItems">
                                    <!-- 这里会通过JavaScript动态添加商品行 -->
                                </tbody>
                            </table>
                            <div style="margin-top: 10px;">
                                <select id="product_selector" class="form-control" style="width: auto; display: inline-block;">
                                    <option value="">-- 选择商品 --</option>
                                    <?php foreach ($products as $product): ?>
                                        <option value="<?php echo $product['id']; ?>"
                                            data-name="<?php echo htmlspecialchars($product['name']); ?>"
                                            data-code="<?php echo htmlspecialchars($product['code']); ?>"
                                            data-price="<?php echo $product['price']; ?>"
                                            data-stock="<?php echo $product['stock']; ?>">
                                            <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <button type="button" id="addProduct" class="btn btn-primary">添加商品</button>
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="remark">订单备注</label>
                        <textarea id="remark" name="remark" class="form-control" rows="3"></textarea>
                    </div>

                    <div class="form-actions">
                        <button type="submit" id="submitOrder" class="btn btn-success">创建订单</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑订单表单 -->
            <div id="editOrderForm" class="form-container" style="display: none;">
                <h3>编辑订单</h3>
                <form method="post" action="list.php" id="editForm">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="order_id" id="edit_order_id">

                    <div class="form-group">
                        <label for="edit_member_id">会员</label>
                        <select id="edit_member_id" name="member_id" class="form-control">
                            <option value="">-- 非会员 --</option>
                            <?php foreach ($members as $member): ?>
                                <option value="<?php echo $member['id']; ?>"><?php echo htmlspecialchars($member['name'] . ' (' . $member['phone'] . ')'); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="edit_store_id">门店</label>
                        <select id="edit_store_id" name="store_id" class="form-control" required>
                            <?php foreach ($stores as $store): ?>
                                <option value="<?php echo $store['id']; ?>"><?php echo htmlspecialchars($store['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="edit_status">订单状态</label>
                        <select id="edit_status" name="status" required>
                            <option value="1">待付款</option>
                            <option value="2">已付款</option>
                            <option value="3">待配送</option>
                            <option value="4">已完成</option>
                            <option value="5">已取消</option>
                            <option value="6">退款中</option>
                            <option value="7">已退款</option>
                        </select>
                    </div>

                    <!-- 商品编辑 -->
                    <div class="form-group">
                        <label>订单商品</label>
                        <div class="table-container">
                            <table class="data-table" id="editProductTable">
                                <thead>
                                    <tr>
                                        <th>商品名称</th>
                                        <th>单价</th>
                                        <th>数量</th>
                                        <th>小计</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody id="editOrderItems">
                                    <!-- 这里会通过JavaScript动态添加商品行 -->
                                </tbody>
                            </table>
                            <div style="margin-top: 10px;">
                                <select id="edit_product_selector" class="form-control" style="width: auto; display: inline-block;">
                                    <option value="">-- 选择商品 --</option>
                                    <?php foreach ($products as $product): ?>
                                        <option value="<?php echo $product['id']; ?>"
                                            data-name="<?php echo htmlspecialchars($product['name']); ?>"
                                            data-code="<?php echo htmlspecialchars($product['code']); ?>"
                                            data-price="<?php echo $product['price']; ?>"
                                            data-stock="<?php echo $product['stock']; ?>">
                                            <?php echo htmlspecialchars($product['name'] . ' (' . $product['code'] . ')'); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <button type="button" id="editAddProduct" class="btn btn-primary">添加商品</button>
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="edit_total_amount">订单总额</label>
                        <input type="number" id="edit_total_amount" name="total_amount" min="0" step="0.01" readonly>
                    </div>

                    <div class="form-group">
                        <label for="edit_discount_amount">折扣金额</label>
                        <input type="number" id="edit_discount_amount" name="discount_amount" min="0" step="0.01">
                    </div>

                    <div class="form-group">
                        <label for="edit_actual_amount">实付金额</label>
                        <input type="number" id="edit_actual_amount" name="actual_amount" min="0" step="0.01" readonly>
                    </div>

                    <div class="form-group">
                        <label for="edit_remark">备注</label>
                        <textarea id="edit_remark" name="remark" class="form-control" rows="3"></textarea>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideEditForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 订单列表 -->
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>会员</th>
                            <th>门店</th>
                            <th>订单金额</th>
                            <th>实付金额</th>
                            <th>状态</th>
                            <th>下单时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($orders)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无订单数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                    <td><?php echo $order['member_id'] ? htmlspecialchars($order['member_name']) : '非会员'; ?></td>
                                    <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                                    <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                                    <td>￥<?php echo number_format($order['actual_amount'], 2); ?></td>
                                    <td class="<?php echo get_status_class($order['status']); ?>">
                                        <?php echo get_status_text($order['status']); ?>
                                    </td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($order['create_time'])); ?></td>
                                    <td>
                                        <a href="info.php?id=<?php echo $order['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if (has_permission('order.edit')): ?>
                                            <button class="btn btn-sm btn-primary" onclick="editOrder(<?php echo $order['id']; ?>, <?php echo $order['status']; ?>, '<?php echo htmlspecialchars(addslashes($order['remark'])); ?>')">编辑</button>
                                            <?php if (in_array($order['status'], [5, 7])): ?>
                                                <button class="btn btn-sm btn-danger" onclick="deleteOrder(<?php echo $order['id']; ?>, '<?php echo htmlspecialchars($order['order_no']); ?>')">删除</button>
                                            <?php endif; ?>
                                            <?php if ($order['status'] == 3): // 3表示待配送状态 
                                            ?>
                                                <a href="../delivery/create_delivery_task.php?order_id=<?php echo $order['id']; ?>" class="btn btn-sm btn-primary">创建配送任务</a>
                                            <?php endif; ?>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 分页 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($current_page > 1): ?>
                        <a href="list.php?page=1<?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($member_name) ? '&member_name=' . urlencode($member_name) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">首页</a>
                        <a href="list.php?page=<?php echo $current_page - 1; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($member_name) ? '&member_name=' . urlencode($member_name) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">上一页</a>
                    <?php endif; ?>

                    <?php
                    // 显示当前页码附近的页码
                    $start_page = max(1, $current_page - 2);
                    $end_page = min($total_pages, $current_page + 2);

                    for ($i = $start_page; $i <= $end_page; $i++):
                    ?>
                        <a href="list.php?page=<?php echo $i; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($member_name) ? '&member_name=' . urlencode($member_name) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link <?php echo $i == $current_page ? 'current' : ''; ?>"><?php echo $i; ?></a>
                    <?php endfor; ?>

                    <?php if ($current_page < $total_pages): ?>
                        <a href="list.php?page=<?php echo $current_page + 1; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($member_name) ? '&member_name=' . urlencode($member_name) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">下一页</a>
                        <a href="list.php?page=<?php echo $total_pages; ?><?php echo !empty($order_no) ? '&order_no=' . urlencode($order_no) : ''; ?><?php echo !empty($member_name) ? '&member_name=' . urlencode($member_name) : ''; ?><?php echo $status_filter > 0 ? '&status=' . $status_filter : ''; ?><?php echo !empty($start_date) ? '&start_date=' . urlencode($start_date) : ''; ?><?php echo !empty($end_date) ? '&end_date=' . urlencode($end_date) : ''; ?>" class="page-link">末页</a>
                    <?php endif; ?>
                </div>
                <div class="pagination-info">
                    共 <?php echo $total_items; ?> 条记录，当前第 <?php echo $current_page; ?>/<?php echo $total_pages; ?> 页
                </div>
            <?php endif; ?>

            <!-- 删除订单表单 -->
            <form id="deleteOrderForm" method="post" action="list.php" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="order_id" id="delete_order_id">
            </form>
        </div>
    </div>

    <script>
        // 显示添加订单表单
        function showAddForm() {
            document.getElementById('addOrderForm').style.display = 'block';
        }

        // 隐藏添加订单表单
        function hideAddForm() {
            document.getElementById('addOrderForm').style.display = 'none';
        }
        function hideEditForm() {
            document.getElementById('editOrderForm').style.display = 'none';
        }
        // 显示编辑订单表单
        function editOrder(id, status, remark) {
            // 获取订单信息
            fetch('list.php?action=get_order_data&id=' + id)
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        const order = data.order;
                        const items = data.items;

                        document.getElementById('edit_order_id').value = order.id;
                        document.getElementById('edit_member_id').value = order.member_id || '';
                        document.getElementById('edit_store_id').value = order.store_id;
                        document.getElementById('edit_status').value = order.status;
                        document.getElementById('edit_total_amount').value = order.total_amount;
                        document.getElementById('edit_discount_amount').value = order.discount_amount;
                        document.getElementById('edit_actual_amount').value = order.actual_amount;
                        document.getElementById('edit_remark').value = order.remark;

                        // 清空商品表
                        const tbody = document.getElementById('editOrderItems');
                        tbody.innerHTML = '';

                        // 添加商品行
                        items.forEach(item => {
                            const row = tbody.insertRow();
                            row.innerHTML = `
                                <td>
                                    ${item.product_name} (${item.product_code})
                                    <input type="hidden" name="product_id[]" value="${item.product_id}">
                                    <input type="hidden" name="product_name[]" value="${item.product_name}">
                                    <input type="hidden" name="product_code[]" value="${item.product_code}">
                                </td>
                                <td>
                                    ￥${parseFloat(item.price).toFixed(2)}
                                    <input type="hidden" name="price[]" value="${item.price}">
                                </td>
                                <td>
                                    <input type="number" name="quantity[]" value="${item.quantity}" min="1" style="width: 60px;" 
                                           onchange="updateEditSubtotal(this, ${item.price})">
                                </td>
                                <td>
                                    ￥<span class="subtotal">${parseFloat(item.subtotal).toFixed(2)}</span>
                                </td>
                                <td>
                                    <button type="button" class="btn btn-sm btn-danger" onclick="removeEditRow(this)">删除</button>
                                </td>
                            `;
                        });

                        // 显示表单
                        document.getElementById('editOrderForm').style.display = 'block';
                    } else {
                        alert('获取订单数据失败：' + data.message);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('获取订单数据时发生错误');
                });
        }

        // 添加商品到编辑订单
        document.getElementById('editAddProduct').addEventListener('click', function() {
            const select = document.getElementById('edit_product_selector');
            const option = select.options[select.selectedIndex];

            if (select.value) {
                const productId = select.value;
                const productName = option.getAttribute('data-name');
                const productCode = option.getAttribute('data-code');
                const price = parseFloat(option.getAttribute('data-price'));

                addEditProductRow(productId, productName, productCode, price);
                select.selectedIndex = 0;

                // 更新总金额
                updateEditTotalAmount();
            }
        });

        function addEditProductRow(id, name, code, price) {
            const tbody = document.getElementById('editOrderItems');
            const row = tbody.insertRow();

            row.innerHTML = `
                <td>
                    ${name} (${code})
                    <input type="hidden" name="product_id[]" value="${id}">
                    <input type="hidden" name="product_name[]" value="${name}">
                    <input type="hidden" name="product_code[]" value="${code}">
                </td>
                <td>
                    ￥${price.toFixed(2)}
                    <input type="hidden" name="price[]" value="${price}">
                </td>
                <td>
                    <input type="number" name="quantity[]" value="1" min="1" style="width: 60px;" 
                           onchange="updateEditSubtotal(this, ${price})">
                </td>
                <td>
                    ￥<span class="subtotal">${price.toFixed(2)}</span>
                </td>
                <td>
                    <button type="button" class="btn btn-sm btn-danger" onclick="removeEditRow(this)">删除</button>
                </td>
            `;

            // 更新总金额
            updateEditTotalAmount();
        }

        function updateEditSubtotal(input, price) {
            const quantity = parseInt(input.value);
            const row = input.closest('tr');
            const subtotalElem = row.querySelector('.subtotal');

            if (quantity > 0) {
                const subtotal = price * quantity;
                subtotalElem.textContent = subtotal.toFixed(2);

                // 更新总金额
                updateEditTotalAmount();
            }
        }

        function removeEditRow(button) {
            const row = button.closest('tr');
            row.parentNode.removeChild(row);

            // 更新总金额
            updateEditTotalAmount();
        }

        function updateEditTotalAmount() {
            let total = 0;
            const rows = document.getElementById('editOrderItems').rows;

            for (let i = 0; i < rows.length; i++) {
                const subtotalText = rows[i].querySelector('.subtotal').textContent;
                total += parseFloat(subtotalText);
            }

            document.getElementById('edit_total_amount').value = total.toFixed(2);

            // 更新实付金额
            updateEditActualAmount();
        }

        function updateEditActualAmount() {
            const total = parseFloat(document.getElementById('edit_total_amount').value) || 0;
            const discount = parseFloat(document.getElementById('edit_discount_amount').value) || 0;
            const actual = Math.max(0, total - discount);

            document.getElementById('edit_actual_amount').value = actual.toFixed(2);
        }

        // 监听折扣金额变化
        document.getElementById('edit_discount_amount').addEventListener('change', updateEditActualAmount);

        // 验证编辑表单
        document.getElementById('editForm').addEventListener('submit', function(e) {
            const items = document.getElementById('editOrderItems').rows;
            if (items.length === 0) {
                e.preventDefault();
                alert('请至少添加一个商品到订单！');
                return false;
            }
            return true;
        });

        // 删除订单确认
        function deleteOrder(id, order_no) {
            if (confirm('确定要删除订单 "' + order_no + '" 吗？')) {
                document.getElementById('delete_order_id').value = id;
                document.getElementById('deleteOrderForm').submit();
            }
        }

        // 添加商品到订单
        document.getElementById('addProduct').addEventListener('click', function() {
            const select = document.getElementById('product_selector');
            const option = select.options[select.selectedIndex];

            if (select.value) {
                const productId = select.value;
                const productName = option.getAttribute('data-name');
                const productCode = option.getAttribute('data-code');
                const price = parseFloat(option.getAttribute('data-price'));
                const stock = parseInt(option.getAttribute('data-stock'));

                addProductRow(productId, productName, productCode, price, stock);
                select.selectedIndex = 0;
            }
        });

        function addProductRow(id, name, code, price, stock) {
            const tbody = document.getElementById('orderItems');
            const rowCount = tbody.rows.length;
            const row = tbody.insertRow();

            row.innerHTML = `
                <td>
                    ${name} (${code})
                    <input type="hidden" name="product_id[]" value="${id}">
                    <input type="hidden" name="product_name[]" value="${name}">
                    <input type="hidden" name="product_code[]" value="${code}">
                </td>
                <td>
                    ￥${price.toFixed(2)}
                    <input type="hidden" name="price[]" value="${price}">
                </td>
                <td>
                    <input type="number" name="quantity[]" value="1" min="1" max="${stock}" style="width: 60px;" 
                           onchange="updateSubtotal(this, ${price})">
                </td>
                <td>
                    ￥<span class="subtotal">${price.toFixed(2)}</span>
                </td>
                <td>
                    <button type="button" class="btn btn-sm btn-danger" onclick="removeRow(this)">删除</button>
                </td>
            `;
        }

        function updateSubtotal(input, price) {
            const quantity = parseInt(input.value);
            const row = input.closest('tr');
            const subtotalElem = row.querySelector('.subtotal');

            if (quantity > 0) {
                const subtotal = price * quantity;
                subtotalElem.textContent = subtotal.toFixed(2);
            }
        }

        function removeRow(button) {
            const row = button.closest('tr');
            row.parentNode.removeChild(row);
        }

        // 表单提交验证
        document.getElementById('orderForm').addEventListener('submit', function(e) {
            const items = document.getElementById('orderItems').rows;
            if (items.length === 0) {
                e.preventDefault();
                alert('请至少添加一个商品到订单！');
                return false;
            }
            return true;
        });
    </script>
</body>

</html>