<?php
// statistics/sales.php - 销售统计页面
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('statistics.view');

// 记录访问日志
record_log('访问销售统计页面');

// 处理日期筛选
$date_range = isset($_GET['date_range']) ? $_GET['date_range'] : 'month';
$custom_start = isset($_GET['custom_start']) ? $_GET['custom_start'] : '';
$custom_end = isset($_GET['custom_end']) ? $_GET['custom_end'] : '';

// 根据选择的日期范围确定开始和结束日期
$start_date = '';
$end_date = date('Y-m-d');

switch ($date_range) {
    case 'today':
        $start_date = date('Y-m-d');
        break;
    case 'yesterday':
        $start_date = date('Y-m-d', strtotime('-1 day'));
        $end_date = date('Y-m-d', strtotime('-1 day'));
        break;
    case 'week':
        $start_date = date('Y-m-d', strtotime('-7 days'));
        break;
    case 'month':
        $start_date = date('Y-m-d', strtotime('-30 days'));
        break;
    case 'quarter':
        $start_date = date('Y-m-d', strtotime('-90 days'));
        break;
    case 'year':
        $start_date = date('Y-m-d', strtotime('-365 days'));
        break;
    case 'custom':
        if (!empty($custom_start)) {
            $start_date = $custom_start;
        } else {
            $start_date = date('Y-m-d', strtotime('-30 days'));
        }

        if (!empty($custom_end)) {
            $end_date = $custom_end;
        }
        break;
    default:
        $start_date = date('Y-m-d', strtotime('-30 days'));
}

// 销售概览数据
$sales_overview = [
    'total_amount' => 0,
    'total_orders' => 0,
    'avg_order_value' => 0,
    'growth_rate' => 0
];

try {
    // 获取总销售额和订单数
    $stmt = $pdo->prepare("
        SELECT 
            SUM(numeric_value1) as total_amount,
            SUM(numeric_value3) as total_orders
        FROM data_statistics 
        WHERE statistic_type = 'sales' 
        AND period_type = 'day'
        AND STR_TO_DATE(period_value, '%Y%m%d') BETWEEN ? AND ?
    ");
    $stmt->execute([$start_date, $end_date]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($result) {
        $sales_overview['total_amount'] = $result['total_amount'] ?: 0;
        $sales_overview['total_orders'] = $result['total_orders'] ?: 0;

        // 计算平均订单价值
        if ($sales_overview['total_orders'] > 0) {
            $sales_overview['avg_order_value'] = $sales_overview['total_amount'] / $sales_overview['total_orders'];
        }
    }

    // 计算增长率
    $prev_start_date = date('Y-m-d', strtotime($start_date . ' -' . (strtotime($end_date) - strtotime($start_date)) . ' seconds'));
    $prev_end_date = date('Y-m-d', strtotime($start_date . ' -1 day'));

    $stmt = $pdo->prepare("
        SELECT SUM(numeric_value1) as prev_amount
        FROM data_statistics 
        WHERE statistic_type = 'sales' 
        AND period_type = 'day'
        AND STR_TO_DATE(period_value, '%Y%m%d') BETWEEN ? AND ?
    ");
    $stmt->execute([$prev_start_date, $prev_end_date]);
    $prev_result = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($prev_result && $prev_result['prev_amount'] > 0) {
        $prev_amount = $prev_result['prev_amount'];
        $sales_overview['growth_rate'] = round(($sales_overview['total_amount'] - $prev_amount) / $prev_amount * 100, 2);
    }
} catch (PDOException $e) {
    // 错误处理
    $error_message = '获取销售概览数据失败: ' . $e->getMessage();
}

// 按日/周/月销量分析数据
$period_type = isset($_GET['period_type']) ? $_GET['period_type'] : 'day';
$sales_by_period = [];

try {
    $period_format = '';
    $period_group = '';
    $date_format = '';

    switch ($period_type) {
        case 'day':
            $period_format = '%Y%m%d';
            $period_group = '%Y-%m-%d';
            $date_format = 'Y-m-d';
            break;
        case 'week':
            $period_format = '%Y%u';
            $period_group = '%Y-%u';
            $date_format = 'Y年第W周';
            break;
        case 'month':
            $period_format = '%Y%m';
            $period_group = '%Y-%m';
            $date_format = 'Y-m';
            break;
    }

    $stmt = $pdo->prepare("
        SELECT 
            period_value,
            DATE_FORMAT(STR_TO_DATE(
                CASE 
                    WHEN period_type = 'day' THEN period_value
                    WHEN period_type = 'week' THEN CONCAT(SUBSTRING(period_value, 1, 4), '-', SUBSTRING(period_value, 5))
                    WHEN period_type = 'month' THEN CONCAT(SUBSTRING(period_value, 1, 4), '-', SUBSTRING(period_value, 5))
                END,
                CASE 
                    WHEN period_type = 'day' THEN '%Y%m%d'
                    WHEN period_type = 'week' THEN '%Y%u'
                    WHEN period_type = 'month' THEN '%Y%m'
                END
            ), ?) as period_display,
            SUM(numeric_value1) as amount,
            SUM(numeric_value3) as orders
        FROM data_statistics 
        WHERE statistic_type = 'sales' 
        AND period_type = ?
        AND STR_TO_DATE(
            CASE 
                WHEN period_type = 'day' THEN period_value
                WHEN period_type = 'week' THEN CONCAT(SUBSTRING(period_value, 1, 4), '-', SUBSTRING(period_value, 5), '-01')
                WHEN period_type = 'month' THEN CONCAT(SUBSTRING(period_value, 1, 4), '-', SUBSTRING(period_value, 5), '-01')
            END,
            CASE 
                WHEN period_type = 'day' THEN '%Y%m%d'
                WHEN period_type = 'week' THEN '%Y%u-%d'
                WHEN period_type = 'month' THEN '%Y%m-%d'
            END
        ) BETWEEN ? AND ?
        GROUP BY period_value
        ORDER BY period_value ASC
    ");

    $stmt->execute([$period_group, $period_type, $start_date, $end_date]);
    $sales_by_period = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // 错误处理
    $error_message = '获取销量分析数据失败: ' . $e->getMessage();
}

// 热销商品排行
$top_products = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            ds.reference_id as product_id,
            p.name as product_name,
            SUM(ds.numeric_value1) as sales_amount,
            SUM(ds.numeric_value2) as sales_quantity
        FROM data_statistics ds
        JOIN products p ON ds.reference_id = p.id
        WHERE ds.statistic_type = 'product'
        AND ds.period_type = 'day'
        AND STR_TO_DATE(ds.period_value, '%Y%m%d') BETWEEN ? AND ?
        GROUP BY ds.reference_id
        ORDER BY sales_amount DESC
        LIMIT 10
    ");
    $stmt->execute([$start_date, $end_date]);
    $top_products = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // 错误处理
    $error_message = '获取热销商品数据失败: ' . $e->getMessage();
}

// 销售额趋势（按天统计，用于生成趋势图）
$sales_trend = [];

try {
    $stmt = $pdo->prepare("
        SELECT 
            period_value,
            DATE_FORMAT(STR_TO_DATE(period_value, '%Y%m%d'), '%m-%d') as day,
            numeric_value1 as amount
        FROM data_statistics 
        WHERE statistic_type = 'sales' 
        AND period_type = 'day'
        AND STR_TO_DATE(period_value, '%Y%m%d') BETWEEN ? AND ?
        ORDER BY period_value ASC
    ");
    $stmt->execute([$start_date, $end_date]);
    $sales_trend = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // 错误处理
    $error_message = '获取销售趋势数据失败: ' . $e->getMessage();
}

// 准备图表数据
$trend_days = [];
$trend_amounts = [];

foreach ($sales_trend as $item) {
    $trend_days[] = $item['day'];
    $trend_amounts[] = $item['amount'];
}

$trend_days_json = json_encode($trend_days);
$trend_amounts_json = json_encode($trend_amounts);
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售统计 - FloraEase花店管理系统</title>
    <link rel="stylesheet" href="../style.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>销售统计</h2>
            <div class="breadcrumb">
                <a href="index.php">数据统计与分析</a> / 销售统计
            </div>
        </div>

        <div class="content">
            <?php if (!empty($error_message)): ?>
                <div class="alert alert-danger">
                    <?php echo $error_message; ?>
                </div>
            <?php endif; ?>

            <!-- 日期筛选 -->
            <div class="filter-form">
                <form method="get" action="sales.php">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="date_range">时间范围</label>
                            <select id="date_range" name="date_range" onchange="toggleCustomDateFields()">
                                <option value="today" <?php echo $date_range == 'today' ? 'selected' : ''; ?>>今日</option>
                                <option value="yesterday" <?php echo $date_range == 'yesterday' ? 'selected' : ''; ?>>昨日</option>
                                <option value="week" <?php echo $date_range == 'week' ? 'selected' : ''; ?>>近7天</option>
                                <option value="month" <?php echo $date_range == 'month' ? 'selected' : ''; ?>>近30天</option>
                                <option value="quarter" <?php echo $date_range == 'quarter' ? 'selected' : ''; ?>>近90天</option>
                                <option value="year" <?php echo $date_range == 'year' ? 'selected' : ''; ?>>近一年</option>
                                <option value="custom" <?php echo $date_range == 'custom' ? 'selected' : ''; ?>>自定义</option>
                            </select>
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_start">开始日期</label>
                            <input type="date" id="custom_start" name="custom_start" value="<?php echo $custom_start; ?>">
                        </div>
                        <div class="filter-item custom-date" style="display: <?php echo $date_range == 'custom' ? 'block' : 'none'; ?>;">
                            <label for="custom_end">结束日期</label>
                            <input type="date" id="custom_end" name="custom_end" value="<?php echo $custom_end; ?>">
                        </div>
                        <div class="filter-item">
                            <label for="period_type">统计周期</label>
                            <select id="period_type" name="period_type">
                                <option value="day" <?php echo $period_type == 'day' ? 'selected' : ''; ?>>按日</option>
                                <option value="week" <?php echo $period_type == 'week' ? 'selected' : ''; ?>>按周</option>
                                <option value="month" <?php echo $period_type == 'month' ? 'selected' : ''; ?>>按月</option>
                            </select>
                        </div>
                    </div>
                    <div class="filter-buttons">
                        <button type="submit" class="btn btn-primary">查询</button>
                        <a href="sales.php" class="btn btn-secondary">重置</a>
                        <?php if (has_permission('statistics.manage')): ?>
                            <a href="init_sales_data.php" class="btn btn-success">初始化销售数据</a>
                        <?php endif; ?>
                    </div>
                </form>
            </div>

            <!-- 销售概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>销售总额</h3>
                    <div class="number">￥<?php echo number_format($sales_overview['total_amount'], 2); ?></div>
                    <div class="desc">同比增长 <?php echo $sales_overview['growth_rate']; ?>%</div>
                </div>
                <div class="dashboard-card">
                    <h3>订单数量</h3>
                    <div class="number"><?php echo number_format($sales_overview['total_orders']); ?></div>
                    <div class="desc">平均客单价 ￥<?php echo number_format($sales_overview['avg_order_value'], 2); ?></div>
                </div>
                <div class="dashboard-card">
                    <h3>时段</h3>
                    <div class="number"><?php echo $start_date; ?></div>
                    <div class="desc">至 <?php echo $end_date; ?></div>
                </div>
            </div>

            <!-- 销售额趋势图 -->
            <div class="section">
                <h2>销售额趋势</h2>
                <div class="chart-container" style="position: relative; height:300px;">
                    <canvas id="salesTrendChart"></canvas>
                </div>
            </div>

            <!-- 按周期销量分析 -->
            <div class="section">
                <h2>按<?php echo $period_type == 'day' ? '日' : ($period_type == 'week' ? '周' : '月'); ?>销量分析</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th><?php echo $period_type == 'day' ? '日期' : ($period_type == 'week' ? '周次' : '月份'); ?></th>
                                <th>销售额</th>
                                <th>订单数</th>
                                <th>均单价</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($sales_by_period)): ?>
                                <?php foreach ($sales_by_period as $item): ?>
                                    <tr>
                                        <td><?php echo $item['period_display']; ?></td>
                                        <td>￥<?php echo number_format($item['amount'], 2); ?></td>
                                        <td><?php echo $item['orders']; ?></td>
                                        <td>￥<?php echo $item['orders'] > 0 ? number_format($item['amount'] / $item['orders'], 2) : '0.00'; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="4" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- 热销商品排行 -->
            <div class="section">
                <h2>热销商品排行</h2>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>排名</th>
                                <th>商品名称</th>
                                <th>销售额</th>
                                <th>销售数量</th>
                                <th>均价</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (!empty($top_products)): ?>
                                <?php foreach ($top_products as $index => $product): ?>
                                    <tr>
                                        <td><?php echo $index + 1; ?></td>
                                        <td><?php echo htmlspecialchars($product['product_name']); ?></td>
                                        <td>￥<?php echo number_format($product['sales_amount'], 2); ?></td>
                                        <td><?php echo number_format($product['sales_quantity']); ?></td>
                                        <td>￥<?php echo $product['sales_quantity'] > 0 ? number_format($product['sales_amount'] / $product['sales_quantity'], 2) : '0.00'; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <script>
        // 控制自定义日期字段的显示与隐藏
        function toggleCustomDateFields() {
            var dateRange = document.getElementById('date_range').value;
            var customDateFields = document.querySelectorAll('.custom-date');

            for (var i = 0; i < customDateFields.length; i++) {
                customDateFields[i].style.display = dateRange === 'custom' ? 'block' : 'none';
            }
        }

        // 绘制销售额趋势图
        var ctx = document.getElementById('salesTrendChart').getContext('2d');
        var salesTrendChart = new Chart(ctx, {
            type: 'line',
            data: {
                labels: <?php echo $trend_days_json; ?>,
                datasets: [{
                    label: '销售额',
                    data: <?php echo $trend_amounts_json; ?>,
                    backgroundColor: 'rgba(76, 175, 80, 0.2)',
                    borderColor: 'rgba(76, 175, 80, 1)',
                    borderWidth: 1,
                    tension: 0.4
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '销售额（元）'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '日期'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '销售额趋势'
                    },
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                return '销售额: ￥' + context.parsed.y.toLocaleString('zh-CN', {
                                    minimumFractionDigits: 2,
                                    maximumFractionDigits: 2
                                });
                            }
                        }
                    }
                }
            }
        });
    </script>
</body>

</html>