<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system_backup');

// 记录访问日志
record_log('访问数据备份页面');

// 备份目录
$backup_dir = '../backups/';

// 如果备份目录不存在，则创建
if (!is_dir($backup_dir)) {
    mkdir($backup_dir, 0755, true);
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 创建备份
    if ($_POST['action'] == 'backup') {
        $backup_name = isset($_POST['backup_name']) ? trim($_POST['backup_name']) : '';

        if (empty($backup_name)) {
            $backup_name = 'backup_' . date('YmdHis');
        }

        // 生成唯一文件名
        $backup_file = $backup_dir . $backup_name . '.sql';

        // Windows环境下使用mysqldump执行备份
        $command = sprintf(
            'mysqldump -h %s -u %s -p%s %s > "%s"',
            DB_HOST,
            DB_USER,
            DB_PASS,
            DB_NAME,
            $backup_file
        );

        // 执行备份命令
        $output = [];
        $return_var = 0;
        exec($command, $output, $return_var);

        if ($return_var === 0) {
            // 记录备份信息到数据库
            try {
                $stmt = $pdo->prepare("INSERT INTO sys_backups (backup_name, backup_path) VALUES (?, ?)");
                $result = $stmt->execute([$backup_name, $backup_file]);

                if ($result) {
                    record_log("创建数据库备份：{$backup_name}");
                    $success = '数据库备份成功！';
                } else {
                    $error = '记录备份信息失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        } else {
            $error = '数据库备份失败！请检查系统环境或联系管理员。';
        }
    }

    // 恢复备份
    elseif ($_POST['action'] == 'restore') {
        $backup_id = isset($_POST['backup_id']) ? intval($_POST['backup_id']) : 0;

        if ($backup_id <= 0) {
            $error = '无效的备份ID！';
        } else {
            try {
                // 获取备份文件路径
                $stmt = $pdo->prepare("SELECT backup_path FROM sys_backups WHERE id = ?");
                $stmt->execute([$backup_id]);
                $backup = $stmt->fetch();

                if (!$backup || !file_exists($backup['backup_path'])) {
                    $error = '备份文件不存在！';
                } else {
                    // Windows环境下使用mysql执行恢复
                    $command = sprintf(
                        'mysql -h %s -u %s -p%s %s < "%s"',
                        DB_HOST,
                        DB_USER,
                        DB_PASS,
                        DB_NAME,
                        $backup['backup_path']
                    );

                    // 执行恢复命令
                    $output = [];
                    $return_var = 0;
                    exec($command, $output, $return_var);

                    if ($return_var === 0) {
                        record_log("恢复数据库备份：ID {$backup_id}");
                        $success = '数据库恢复成功！';
                    } else {
                        $error = '数据库恢复失败！请检查系统环境或联系管理员。';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除备份
    elseif ($_POST['action'] == 'delete') {
        $backup_id = isset($_POST['backup_id']) ? intval($_POST['backup_id']) : 0;

        if ($backup_id <= 0) {
            $error = '无效的备份ID！';
        } else {
            try {
                // 获取备份文件路径
                $stmt = $pdo->prepare("SELECT backup_path FROM sys_backups WHERE id = ?");
                $stmt->execute([$backup_id]);
                $backup = $stmt->fetch();

                // 删除备份记录
                $stmt = $pdo->prepare("DELETE FROM sys_backups WHERE id = ?");
                $result = $stmt->execute([$backup_id]);

                if ($result) {
                    // 如果文件存在，删除文件
                    if ($backup && file_exists($backup['backup_path'])) {
                        unlink($backup['backup_path']);
                    }

                    record_log("删除数据库备份：ID {$backup_id}");
                    $success = '备份删除成功！';
                } else {
                    $error = '备份删除失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有备份记录
try {
    $stmt = $pdo->query("SELECT * FROM sys_backups ORDER BY id DESC");
    $backups = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取备份列表失败：' . $e->getMessage();
    $backups = [];
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>数据备份</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 数据备份
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showBackupForm()">创建备份</button>
            </div>

            <!-- 创建备份表单 -->
            <div id="backupForm" class="form-container" style="display: none;">
                <h3>创建数据库备份</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="backup">

                    <div class="form-group">
                        <label for="backup_name">备份名称：</label>
                        <input type="text" id="backup_name" name="backup_name" placeholder="默认使用日期时间">
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">立即备份</button>
                        <button type="button" class="btn btn-secondary" onclick="hideBackupForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 备份列表 -->
            <div class="table-responsive">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>备份名称</th>
                            <th>备份路径</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($backups)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无备份记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($backups as $backup): ?>
                                <tr>
                                    <td><?php echo $backup['id']; ?></td>
                                    <td><?php echo htmlspecialchars($backup['backup_name']); ?></td>
                                    <td><?php echo htmlspecialchars($backup['backup_path']); ?></td>
                                    <td><?php echo $backup['create_time']; ?></td>
                                    <td>
                                        <button class="btn btn-sm btn-success" onclick="restoreBackup(<?php echo $backup['id']; ?>, '<?php echo htmlspecialchars($backup['backup_name']); ?>')">恢复</button>
                                        <button class="btn btn-sm btn-danger" onclick="deleteBackup(<?php echo $backup['id']; ?>, '<?php echo htmlspecialchars($backup['backup_name']); ?>')">删除</button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 恢复备份表单 -->
            <form id="restoreForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="restore">
                <input type="hidden" name="backup_id" id="restore_backup_id">
            </form>

            <!-- 删除备份表单 -->
            <form id="deleteForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="backup_id" id="delete_backup_id">
            </form>

            <div class="info-box">
                <h3>备份说明</h3>
                <ul>
                    <li>系统自动备份依赖于MySQL环境和mysqldump命令。</li>
                    <li>备份文件保存在网站根目录的backups文件夹中。</li>
                    <li>建议定期备份数据库，以防数据丢失。</li>
                    <li>恢复操作会覆盖当前数据库中的所有数据，请谨慎操作。</li>
                </ul>
            </div>
        </div>
    </div>

    <script>
        // 显示备份表单
        function showBackupForm() {
            document.getElementById('backupForm').style.display = 'block';
        }

        // 隐藏备份表单
        function hideBackupForm() {
            document.getElementById('backupForm').style.display = 'none';
        }

        // 恢复备份确认
        function restoreBackup(id, name) {
            if (confirm('确定要恢复备份 "' + name + '" 吗？当前数据将被覆盖！')) {
                document.getElementById('restore_backup_id').value = id;
                document.getElementById('restoreForm').submit();
            }
        }

        // 删除备份确认
        function deleteBackup(id, name) {
            if (confirm('确定要删除备份 "' + name + '" 吗？此操作不可恢复！')) {
                document.getElementById('delete_backup_id').value = id;
                document.getElementById('deleteForm').submit();
            }
        }
    </script>
</body>

</html>